@@ -44,9 +44,19 @@ def count_reads_in_features(sam_filenames, gff_filename,
                 read.optional_fields.append(('XF', assignment))
                 samoutfile.write(read.get_sam_line() + "\n")
 
+    if samtype == "sam":
+        SAM_or_BAM_Reader = HTSeq.SAM_Reader
+        samname = 'SAM'
+    elif samtype == "bam":
+        SAM_or_BAM_Reader = HTSeq.BAM_Reader
+        samname = 'BAM'
+    else:
+        raise ValueError("Unknown input format %s specified." % samtype)
+
     if samouts != []:
         if len(samouts) != len(sam_filenames):
-            raise ValueError('Select the same number of SAM input and output files')
+            raise ValueError(
+                    'Select the same number of {:} input and output files'.format(samname))
         # Try to open samout files early in case any of them has issues
         for samout in samouts:
             with open(samout, 'w'):
@@ -73,12 +83,14 @@ def count_reads_in_features(sam_filenames, gff_filename,
                 try:
                     feature_id = f.attr[id_attribute]
                 except KeyError:
-                    raise ValueError("Feature %s does not contain a '%s' attribute" %
-                                     (f.name, id_attribute))
+                    raise ValueError(
+                            "Feature %s does not contain a '%s' attribute" %
+                            (f.name, id_attribute))
                 if stranded != "no" and f.iv.strand == ".":
-                    raise ValueError("Feature %s at %s does not have strand information but you are "
-                                     "running htseq-count in stranded mode. Use '--stranded=no'." %
-                                     (f.name, f.iv))
+                    raise ValueError(
+                            "Feature %s at %s does not have strand information but you are "
+                            "running htseq-count in stranded mode. Use '--stranded=no'." %
+                            (f.name, f.iv))
                 features[f.iv] += feature_id
                 counts[f.attr[id_attribute]] = 0
                 attributes[f.attr[id_attribute]] = [
@@ -102,13 +114,6 @@ def count_reads_in_features(sam_filenames, gff_filename,
         sys.stderr.write(
             "Warning: No features of type '%s' found.\n" % feature_type)
 
-    if samtype == "sam":
-        SAM_or_BAM_Reader = HTSeq.SAM_Reader
-    elif samtype == "bam":
-        SAM_or_BAM_Reader = HTSeq.BAM_Reader
-    else:
-        raise ValueError("Unknown input format %s specified." % samtype)
-
     counts_all = []
     empty_all = []
     ambiguous_all = []
@@ -140,7 +145,8 @@ def count_reads_in_features(sam_filenames, gff_filename,
                 read_seq = []
         except:
             sys.stderr.write(
-                "Error occured when reading beginning of SAM/BAM file.\n")
+                "Error occured when reading beginning of {:} file.\n".format(
+                    samname))
             raise
 
         try:
@@ -170,8 +176,8 @@ def count_reads_in_features(sam_filenames, gff_filename,
             for r in read_seq:
                 if i > 0 and i % 100000 == 0 and not quiet:
                     sys.stderr.write(
-                        "%d SAM alignment record%s processed.\n" %
-                        (i, "s" if not pe_mode else " pairs"))
+                        "%d %s alignment record%s processed.\n" %
+                        (i, samname, "s" if not pe_mode else " pairs"))
                     sys.stderr.flush()
 
                 i += 1
@@ -189,7 +195,10 @@ def count_reads_in_features(sam_filenames, gff_filename,
                     try:
                         if r.optional_field("NH") > 1:
                             nonunique += 1
-                            write_to_samout(r, "__alignment_not_unique", samoutfile)
+                            write_to_samout(
+                                    r,
+                                    "__alignment_not_unique",
+                                    samoutfile)
                             if multimapped_mode == 'none':
                                 continue
                     except KeyError:
@@ -307,14 +316,14 @@ def count_reads_in_features(sam_filenames, gff_filename,
 
         except:
             sys.stderr.write(
-                "Error occured when processing SAM input (%s):\n" %
-                read_seq_file.get_line_number_string())
+                "Error occured when processing %s input (%s):\n" %
+                (samname, read_seq_file.get_line_number_string()))
             raise
 
         if not quiet:
             sys.stderr.write(
-                "%d SAM %s processed.\n" %
-                (i, "alignments " if not pe_mode else "alignment pairs"))
+                "%d %s %s processed.\n" %
+                (i, samname, "alignments " if not pe_mode else "alignment pairs"))
             sys.stderr.flush()
 
         if samoutfile is not None:
@@ -339,7 +348,8 @@ def count_reads_in_features(sam_filenames, gff_filename,
     print('\t'.join(["__alignment_not_unique"] + pad + [str(c) for c in nonunique_all]))
 
 
-def my_showwarning(message, category, filename, lineno=None, file=None, line=None):
+def my_showwarning(message, category, filename, lineno=None, file=None,
+                   line=None):
     sys.stderr.write("Warning: %s\n" % message)
 
 
@@ -352,7 +362,8 @@ def main():
         "the number of reads mapping to it. See " +
         "http://htseq.readthedocs.io/en/master/count.html for details.",
         epilog="Written by Simon Anders (sanders@fs.tum.de), " +
-        "European Molecular Biology Laboratory (EMBL). (c) 2010. " +
+        "European Molecular Biology Laboratory (EMBL) and Fabio Zanini " +
+        "(fabio.zanini@stanford.edu), Stanford University. (c) 2010-2019. " +
         "Released under the terms of the GNU General Public License v3. " +
         "Part of the 'HTSeq' framework, version %s." % HTSeq.__version__)
 
@@ -363,12 +374,12 @@ def main():
 
     pa.add_argument(
             "featuresfilename", type=str,
-            help="Path to the file containing the features")
+            help="Path to the GTF file containing the features")
 
     pa.add_argument(
             "-f", "--format", dest="samtype",
             choices=("sam", "bam"), default="sam",
-            help="type of <alignment_file> data, either 'sam' or 'bam' (default: sam)")
+            help="Type of <alignment_file> data, either 'sam' or 'bam' (default: sam)")
 
     pa.add_argument(
             "-r", "--order", dest="order",
@@ -388,38 +399,43 @@ def main():
     pa.add_argument(
             "-s", "--stranded", dest="stranded",
             choices=("yes", "no", "reverse"), default="yes",
-            help="whether the data is from a strand-specific assay. Specify 'yes', " +
+            help="Whether the data is from a strand-specific assay. Specify 'yes', " +
             "'no', or 'reverse' (default: yes). " +
             "'reverse' means 'yes' with reversed strand interpretation")
 
     pa.add_argument(
             "-a", "--minaqual", type=int, dest="minaqual",
             default=10,
-            help="skip all reads with alignment quality lower than the given " +
-            "minimum value (default: 10)")
+            help="Skip all reads with MAPQ alignment quality lower than the given " +
+            "minimum value (default: 10). MAPQ is the 5th column of a SAM/BAM " +
+            "file and its usage depends on the software used to map the reads.")
 
     pa.add_argument(
             "-t", "--type", type=str, dest="featuretype",
-            default="exon", help="feature type (3rd column in GFF file) to be used, " +
+            default="exon",
+            help="Feature type (3rd column in GTF file) to be used, " +
             "all features of other type are ignored (default, suitable for Ensembl " +
             "GTF files: exon)")
 
     pa.add_argument(
             "-i", "--idattr", type=str, dest="idattr",
-            default="gene_id", help="GFF attribute to be used as feature ID (default, " +
+            default="gene_id",
+            help="GTF attribute to be used as feature ID (default, " +
             "suitable for Ensembl GTF files: gene_id)")
 
     pa.add_argument(
             "--additional-attr", type=str,
             action='append',
-            default=[], help="Additional feature attributes (default: none, " +
+            default=[],
+            help="Additional feature attributes (default: none, " +
             "suitable for Ensembl GTF files: gene_name). Use multiple times " +
             "for each different attribute")
 
     pa.add_argument(
             "-m", "--mode", dest="mode",
             choices=("union", "intersection-strict", "intersection-nonempty"),
-            default="union", help="mode to handle reads overlapping more than one feature " +
+            default="union",
+            help="Mode to handle reads overlapping more than one feature " +
             "(choices: union, intersection-strict, intersection-nonempty; default: union)")
 
     pa.add_argument(
@@ -441,16 +457,25 @@ def main():
     pa.add_argument(
             "-o", "--samout", type=str, dest="samouts",
             action='append',
-            default=[], help="write out all SAM alignment records into " +
+            default=[],
+            help="Write out all SAM alignment records into " +
             "SAM files (one per input file needed), annotating each line " +
             "with its feature assignment (as an optional field with tag 'XF')")
 
     pa.add_argument(
             "-q", "--quiet", action="store_true", dest="quiet",
-            help="suppress progress report")  # and warnings" )
+            help="Suppress progress report")  # and warnings" )
+
+    pa.add_argument(
+            "--version", action="store_true",
+            help='Show software version and exit')
 
     args = pa.parse_args()
 
+    if args.version:
+        print(HTSeq.__version__)
+        sys.exit()
+
     warnings.showwarning = my_showwarning
     try:
         count_reads_in_features(
